@@ -9,13 +9,13 @@ import requests
 class KafkaConnect():
     """A client for the Confluent Platform Kafka Connect REST API.
     Args:
-        endpoint (str): The base URL for the Kafka Connect REST API.
+        url (str): The base URL for the Kafka Connect REST API.
         auth (str): A colon-delimited string of `username` and `password` to use for authenticating with the Kafka Connect REST API.
         ssl_verify (bool): Whether to verify the SSL certificate when making requests to the Kafka Connect REST API. Defaults to True.
         logger (logging.Logger): The logger to be used. If not specified, a new logger will be created.
     """
-    def __init__(self, endpoint="http://localhost:8083", auth=None, ssl_verify=True, logger=None):
-        self.endpoint = endpoint
+    def __init__(self, url="http://localhost:8083", auth=None, ssl_verify=True, logger=None):
+        self.url = url
         self.headers = {"Content-Type": "application/json"}
 
         # Split the auth string into username and password and store them as a tuple
@@ -41,43 +41,44 @@ class KafkaConnect():
             Dict[str, str]: The details of the cluster, including its version, commit ID, and Kafka cluster ID.
         """
         self.logger.info("Getting cluster details")
-        url = f"{self.endpoint}"
+        url = f"{self.url}"
         response = requests.get(url, auth=self.auth, verify=self.verify)
         response.raise_for_status()
         return response.json()
 
-    def list_connectors(self, expand=None, connector_pattern=None):
+    def __filter(self, connectors, pattern):
+        """Filter connectors based on a regex pattern.
+        Args:
+            connectors (List[str] or Dict[str, Any]): The list or dictionary of connectors to filter.
+            pattern (str): The regex pattern to match the connector name.
+        Returns:
+            List[str] or Dict[str, Any]: The filtered connectors.
+        """
+        if not pattern:
+            filtered_connectors = connectors
+        elif isinstance(connectors, list):
+            filtered_connectors = [conn for conn in connectors if re.match(pattern, conn)]
+        elif isinstance(connectors, dict):
+            filtered_connectors = {conn:data for conn, data in connectors.items() if re.match(pattern, conn)}
+        return filtered_connectors
+
+    def list_connectors(self, expand=None, pattern=None):
         """Get the list of connectors.
         Args:
             expand (str): Optional parameter that retrieves additional information about the connectors.
                 Valid values are "status" and "info".
-            connector_pattern (str): The regex pattern to match the connector name. If not provided, all connectors will be listed.
+            pattern (str): The regex pattern to match the connector name. If not provided, all connectors will be listed.
         Returns:
             list or dict: The list of connector names or dictionary of connector names and its details.
         """
         self.logger.info("Listing connectors")
-        url = f"{self.endpoint}/connectors"
+        url = f"{self.url}/connectors"
         params = {"expand": expand}
         response = requests.get(url, auth=self.auth, verify=self.verify, params=params)
         response.raise_for_status()
         connectors = response.json()
 
-        if expand:
-            filtered_connectors = {}
-            for connector, data in connectors.items():
-                if connector_pattern:
-                    if not re.match(connector_pattern, connector):
-                        continue
-                filtered_connectors[connector] = data
-            return filtered_connectors
-        else:
-            filtered_connectors = []
-            for connector in connectors:
-                if connector_pattern:
-                    if not re.match(connector_pattern, connector):
-                        continue
-                filtered_connectors.append(connector)
-            return filtered_connectors
+        return self.__filter(connectors, pattern)
     
     def get_connector(self, connector):
         """Get the details of a single connector.
@@ -87,31 +88,11 @@ class KafkaConnect():
             Dict[str, Any]: The details of the connector.
         """
         self.logger.info(f"Getting connector: {connector}")
-        url = f"{self.endpoint}/connectors/{connector}"
+        url = f"{self.url}/connectors/{connector}"
         response = requests.get(url, auth=self.auth, verify=self.verify)
         response.raise_for_status()
         return response.json()
 
-    def get_all_connectors(self, connector_pattern=None):
-        """Get the details of all connectors.
-        Args:
-            connector_pattern (str): The regex pattern to match the connector name. If not provided, all connectors will be retrieved.
-        Returns:
-            Dict[str, Dict[str, Any]]: A dictionary of responses, where the keys are the connector names and the values are the responses.
-        """
-        self.logger.info(f"Get the details of all connectors{' matching the pattern: ' + connector_pattern if connector_pattern else ''}")
-
-        responses = {}
-        for connector in self.list_connectors():
-            self.logger.debug(f"Filtering {connector}")
-
-            if connector_pattern and not re.match(connector_pattern, connector):
-                continue
-
-            responses[connector] = self.get_connector(connector)
-
-        return responses
-
     def create_connector(self, config):
         """Create a new connector.
         Args:
@@ -122,7 +103,7 @@ class KafkaConnect():
             HTTPError: If the REST API responds with a non-200 status code.
         """
         self.logger.info(f"Creating connector: {config.get('name')}")
-        url = f"{self.endpoint}/connectors"
+        url = f"{self.url}/connectors"
         response = requests.post(url, auth=self.auth, verify=self.verify, headers=self.headers, data=json.dumps(config))
         
         if response.status_code == 409:
@@ -148,7 +129,7 @@ class KafkaConnect():
             self.logger.error('The payload is not wrapped in {"config": {}} as in the POST request. The config is directly provided.')
 
         self.logger.info(f"Updating connector: {connector}")
-        url = f"{self.endpoint}/connectors/{connector}/config"
+        url = f"{self.url}/connectors/{connector}/config"
         response = requests.put(url, headers=self.headers, auth=self.auth, verify=self.verify, data=json.dumps(config))
 
         if response.status_code == 409:
@@ -171,30 +152,10 @@ class KafkaConnect():
             Dict[str, Any]: The configuration of the connector.
         """
         self.logger.info(f"Getting connector config: {connector}")
-        url = f"{self.endpoint}/connectors/{connector}/config"
+        url = f"{self.url}/connectors/{connector}/config"
         response = requests.get(url, auth=self.auth, verify=self.verify)
         response.raise_for_status()
         return response.json()
-    
-    def get_all_connector_configs(self, connector_pattern=None):
-        """Get the config of all connectors.
-        Args:
-            connector_pattern (str): The regex pattern to match the connector name. If not provided, all connector configs will be retrieved.
-        Returns:
-            Dict[str, Dict[str, Any]]: A dictionary of responses, where the keys are the connector names and the values are the responses.
-        """
-        self.logger.info(f"Get the config of all connectors{' matching the pattern: ' + connector_pattern if connector_pattern else ''}")
-
-        responses = {}
-        for connector in self.list_connectors():
-            self.logger.debug(f"Filtering {connector}")
-
-            if connector_pattern and not re.match(connector_pattern, connector):
-                continue
-
-            responses[connector] = self.get_connector_config(connector)
-
-        return responses
 
     def get_connector_status(self, connector):
         """Get the status of a single connector.
@@ -204,30 +165,10 @@ class KafkaConnect():
             Dict[str, Any]: The status of the connector.
         """
         self.logger.info(f"Getting connector status: {connector}")
-        url = f"{self.endpoint}/connectors/{connector}/status"
+        url = f"{self.url}/connectors/{connector}/status"
         response = requests.get(url, auth=self.auth, verify=self.verify)
         response.raise_for_status()
         return response.json()
-    
-    def get_all_connector_statuses(self, connector_pattern=None):
-        """Get the status of all connectors.
-        Args:
-            connector_pattern (str): The regex pattern to match the connector name. If not provided, all connector statuses will be retrieved.
-        Returns:
-            Dict[str, Dict[str, Any]]: A dictionary of responses, where the keys are the connector names and the values are the responses.
-        """
-        self.logger.info(f"Get the status of all connectors{' matching the pattern: ' + connector_pattern if connector_pattern else ''}")
-
-        responses = {}
-        for connector, status in self.list_connectors(expand="status").items():
-            self.logger.debug(f"Filtering {connector}")
-
-            if connector_pattern and not re.match(connector_pattern, connector):
-                continue
-
-            responses[connector] = status
-
-        return responses
 
     def restart_connector(self, connector, include_tasks=False, only_failed=False):
         """Restart a single connector.
@@ -240,7 +181,7 @@ class KafkaConnect():
             Dict[str, Any]: The response from the REST API, or an empty dictionary if the response is null or if there is a JSONDecodeError.
         """
         self.logger.info(f"Restarting connector: {connector}")
-        url = f"{self.endpoint}/connectors/{connector}/restart"
+        url = f"{self.url}/connectors/{connector}/restart"
         params = {"includeTasks": include_tasks, "onlyFailed": only_failed}
         response = requests.post(url, auth=self.auth, verify=self.verify, params=params)
         try:
@@ -270,27 +211,20 @@ class KafkaConnect():
         response.raise_for_status()
         return data
     
-    def restart_all_connectors(self, include_tasks=False, only_failed=False, connector_pattern=None):
+    def restart_all_connectors(self, include_tasks=False, only_failed=False, pattern=None):
         """Restart all connectors.
         Args:
             include_tasks (bool): Whether to include tasks when restarting the connector. Default is False.
             only_failed (bool): Whether to only restart failed tasks. Default is False.
-            connector_pattern (str): The regex pattern to match the connector name. If not provided, all connectors will be restarted.
+            pattern (str): The regex pattern to match the connector name. If not provided, all connectors will be restarted.
         Returns:
             Dict[str, Dict[str, Any]]: A dictionary of responses, where the keys are the connector names and the values are the responses.
         """
-        self.logger.info(f"Restarting all connectors{' matching the pattern: ' + connector_pattern if connector_pattern else ''}")
-
+        self.logger.info(f"Restarting all connectors{' matching the pattern: ' + pattern if pattern else ''}")
         responses = {}
-        for connector, status in self.list_connectors(expand="status").items():
-            self.logger.debug(f"Filtering {connector} connector: {status}")
-
-            if connector_pattern and not re.match(connector_pattern, connector):
-                continue
-
-            responses[connector] = self.restart_connector(connector, include_tasks, only_failed)
-
-        return responses
+        connectors = self.__filter(self.list_connectors(expand="status"), pattern)
+        for connector, status in connectors.items():
+            self.restart_connector(connector, include_tasks, only_failed)
 
     def pause_connector(self, connector):
         """Pause a single connector.
@@ -300,7 +234,7 @@ class KafkaConnect():
             Dict[str, Any]: The response from the REST API, or an empty dictionary if the response is null or if there is a JSONDecodeError.
         """
         self.logger.info(f"Pausing connector: {connector}")
-        url = f"{self.endpoint}/connectors/{connector}/pause"
+        url = f"{self.url}/connectors/{connector}/pause"
         response = requests.put(url, auth=self.auth, verify=self.verify)
         response.raise_for_status()
         try:
@@ -309,28 +243,17 @@ class KafkaConnect():
             data = None
         return data
     
-    def pause_all_connectors(self, connector_pattern=None):
+    def pause_all_connectors(self, pattern=None):
         """Pause all connectors.
         Args:
-            connector_pattern (str): The regex pattern to match the connector name. If not provided, all running connectors will be paused.
+            pattern (str): The regex pattern to match the connector name. If not provided, all running connectors will be paused.
         Returns:
             Dict[str, Dict[str, Any]]: A dictionary of responses, where the keys are the connector names and the values are the responses.
         """
-        self.logger.info(f"Pausing all running connectors{' matching the pattern: ' + connector_pattern if connector_pattern else ''}")
-        
-        responses = {}
-        for connector, status in self.list_connectors(expand="status").items():
-            self.logger.debug(f"Filtering {connector} connector: {status}")
-
-            if connector_pattern and not re.match(connector_pattern, connector):
-                continue
-
-            if status.get("status", {}).get("connector", {}).get("state", None).upper() == "RUNNING":
-                responses[connector] = self.pause_connector(connector)
-            else:
-                self.logger.debug(f"Skipping the {connector} connector because it is not in a RUNNING state.")
-
-        return responses
+        self.logger.info(f"Pausing all running connectors{' matching the pattern: ' + pattern if pattern else ''}")
+        connectors = self.__filter(self.list_connectors(expand="status"), pattern)
+        for connector, status in connectors.items():
+            self.pause_connector(connector)
 
     def resume_connector(self, connector):
         """Resume a single connector.
@@ -340,7 +263,7 @@ class KafkaConnect():
             Dict[str, Any]: The response from the REST API, or an empty dictionary if the response is null or if there is a JSONDecodeError.
         """
         self.logger.info(f"Resuming connector: {connector}")
-        url = f"{self.endpoint}/connectors/{connector}/resume"
+        url = f"{self.url}/connectors/{connector}/resume"
         response = requests.put(url, auth=self.auth, verify=self.verify)
         response.raise_for_status()
         try:
@@ -349,27 +272,17 @@ class KafkaConnect():
             data = None
         return data
 
-    def resume_all_connectors(self, connector_pattern=None):
+    def resume_all_connectors(self, pattern=None):
         """Resume all connectors.
         Args:
-            connector_pattern (str): The regex pattern to match the connector name. If not provided, all paused connectors will be resumed.
+            pattern (str): The regex pattern to match the connector name. If not provided, all paused connectors will be resumed.
         Returns:
             Dict[str, Dict[str, Any]]: A dictionary of responses, where the keys are the connector names and the values are the responses.
         """
-        self.logger.info(f"Resuming all paused connectors{' matching the pattern: ' + connector_pattern if connector_pattern else ''}")
-        responses = {}
-        for connector, status in self.list_connectors(expand="status").items():
-            self.logger.debug(f"Filtering {connector} connector: {status}")
-
-            if connector_pattern and not re.match(connector_pattern, connector):
-                continue
-
-            if status.get("status", {}).get("connector", {}).get("state", None).upper() == "PAUSED":
-                responses[connector] = self.resume_connector(connector)
-            else:
-                self.logger.debug(f"Skipping the {connector} connector because it is not in a PAUSED state.")
-
-        return responses
+        self.logger.info(f"Resuming all paused connectors{' matching the pattern: ' + pattern if pattern else ''}")
+        connectors = self.__filter(self.list_connectors(expand="status"), pattern)
+        for connector, status in connectors.items():
+            self.resume_connector(connector)
 
     def delete_connector(self, connector):
         """Delete a single connector.
@@ -379,7 +292,7 @@ class KafkaConnect():
             Dict[str, Any]: The response from the REST API, or an empty dictionary if the response is null or if there is a JSONDecodeError.
         """
         self.logger.info(f"Deleting connector: {connector}")
-        url = f"{self.endpoint}/connectors/{connector}"
+        url = f"{self.url}/connectors/{connector}"
         response = requests.delete(url, auth=self.auth, verify=self.verify)
         response.raise_for_status()
         try:
@@ -388,24 +301,17 @@ class KafkaConnect():
             data = None
         return data
     
-    def delete_all_connectors(self, connector_pattern=None):
+    def delete_all_connectors(self, pattern=None):
         """Delete all connectors.
         Args:
-            connector_pattern (str): The regex pattern to match the connector name. If not provided, all connectors will be deleted.
+            pattern (str): The regex pattern to match the connector name. If not provided, all connectors will be deleted.
         Returns:
             Dict[str, Dict[str, Any]]: A dictionary of responses, where the keys are the connector names and the values are the responses.
         """
-        self.logger.info(f"Deleting all connectors{' matching the pattern: ' + connector_pattern if connector_pattern else ''}")
-        responses = {}
-        for connector in self.list_connectors():
-            self.logger.debug(f"Filtering connector: {connector}")
-
-            if connector_pattern and not re.match(connector_pattern, connector):
-                continue
-
-            responses[connector] = self.delete_connector(connector)
-
-        return responses
+        self.logger.info(f"Deleting all connectors{' matching the pattern: ' + pattern if pattern else ''}")
+        connectors = self.__filter(self.list_connectors(expand="status"), pattern)
+        for connector, status in connectors.items():
+            self.delete_connector(connector)
 
     def list_connector_tasks(self, connector):
         """Get the list of tasks for a connector.
@@ -415,7 +321,7 @@ class KafkaConnect():
             List[int]: The list of task IDs for the connector.
         """
         self.logger.info(f"Getting tasks for connector: {connector}")
-        url = f"{self.endpoint}/connectors/{connector}/tasks"
+        url = f"{self.url}/connectors/{connector}/tasks"
         response = requests.get(url, auth=self.auth, verify=self.verify)
         response.raise_for_status()
         return response.json()
@@ -429,7 +335,7 @@ class KafkaConnect():
             Dict[str, Any]: The response from the REST API.
         """
         self.logger.info(f"Getting task status for connector: {connector} and task_id: {task_id}")
-        url = f"{self.endpoint}/connectors/{connector}/tasks/{task_id}/status"
+        url = f"{self.url}/connectors/{connector}/tasks/{task_id}/status"
         response = requests.get(url, auth=self.auth, verify=self.verify)
         response.raise_for_status()
         return response.json()
@@ -443,7 +349,7 @@ class KafkaConnect():
             Dict[str, Any]: The response from the REST API, or an empty dictionary if the response is null or if there is a JSONDecodeError.
         """
         self.logger.info(f"Restarting task {task_id} of connector: {connector}")
-        url = f"{self.endpoint}/connectors/{connector}/tasks/{task_id}/restart"
+        url = f"{self.url}/connectors/{connector}/tasks/{task_id}/restart"
         response = requests.post(url, auth=self.auth, verify=self.verify)
         response.raise_for_status()
         try:
@@ -460,7 +366,7 @@ class KafkaConnect():
             List[str]: The list of topics for the connector.
         """
         self.logger.info(f"Getting topics for connector: {connector}")
-        url = f"{self.endpoint}/connectors/{connector}/topics"
+        url = f"{self.url}/connectors/{connector}/topics"
         response = requests.get(url, auth=self.auth, verify=self.verify)
         response.raise_for_status()
         return response.json()
@@ -473,7 +379,7 @@ class KafkaConnect():
             Dict[str, Any]: The response from the REST API, or an empty dictionary if the response is null or if there is a JSONDecodeError.
         """
         self.logger.info(f"Resetting topics for connector: {connector}")
-        url = f"{self.endpoint}/connectors/{connector}/topics/reset"
+        url = f"{self.url}/connectors/{connector}/topics/reset"
         response = requests.put(url, auth=self.auth, verify=self.verify)
         response.raise_for_status()
         try:
@@ -489,7 +395,7 @@ class KafkaConnect():
             List[Dict[str, Any]]: The list of connector plugins.
         """
         self.logger.info("Getting connector plugins")
-        url = f"{self.endpoint}/connector-plugins"
+        url = f"{self.url}/connector-plugins"
         response = requests.get(url, auth=self.auth, verify=self.verify)
         response.raise_for_status()
         return response.json()
@@ -503,7 +409,7 @@ class KafkaConnect():
             Dict[str, Any]: The response from the REST API, or an empty dictionary if the response is null or if there is a JSONDecodeError.
         """
         self.logger.info(f"Validating config for plugin: {plugin}")
-        url = f"{self.endpoint}/connector-plugins/{plugin}/config/validate"
+        url = f"{self.url}/connector-plugins/{plugin}/config/validate"
         response = requests.put(url, auth=self.auth, verify=self.verify, headers=self.headers, data=json.dumps(config))
         response.raise_for_status()
         try:
